--[[
	oUF_Cliche
	Author: Sauerkraut - Clich Altar of Storms US - Heavily based on oUF_Asym and oUF_P3Lim
	Notes: I take no credit for any of the code that follows.  All of the code was written by those credited.  I simply cobbled it together to suit my taste.
	Credits: Dawn, p3lim, Phatrik, Rufio and Lyn for all the inspiration and code I borrowed ;)
--]]

-- ------------------------------------------------------------------------
-- Font, Fontsize and Textures
-- ------------------------------------------------------------------------
local texture = "Interface\\AddOns\\oUF_Cliche\\textures\\minimalist"
local bborder = "Interface\\AddOns\\oUF_Cliche\\textures\\border"
local frameborder = "Interface\\AddOns\\oUF_Cliche\\textures\\frameborder"
local castborder = "Interface\\AddOns\\oUF_Cliche\\textures\\castborder"
local bufftex = "Interface\\AddOns\\oUF_Cliche\\textures\\square"
local debufftex = "Interface\\AddOns\\oUF_Cliche\\textures\\highlight"
local debufftex2 = "Interface\\AddOns\\oUF_Cliche\\textures\\highlight2"
local casttex = "Interface\\AddOns\\oUF_Cliche\\textures\\castbar"
local font = "Interface\\AddOns\\oUF_Cliche\\fonts\\ROADWAY.ttf"
local fontsize = 20
local outline = "THINOUTLINE" 

local useraid = true -- use included raidframes set to false if you prefer to use something like grid as a healer.

-- ------------------------------------------------------------------------
-- Castbar Position
-- ------------------------------------------------------------------------
local playerCastBar_x = 17
local playerCastBar_y = -238
local targetCastBar_x = 283
local targetCastBar_y = -52
local focusCastBar_x = 20
local focusCastBar_y = 140

-- local playerClass = select(2, UnitClass("player"))
local _, class = UnitClass("player")

-- ------------------------------------------------------------------------
-- Set Colors 
-- ------------------------------------------------------------------------
oUF.colors.happiness = {
	[1] = {182/225, 34/255, 32/255},	-- unhappy
	[2] = {220/225, 180/225, 52/225},	-- content
	[3] = {143/255, 194/255, 32/255},	-- happy
}

oUF.colors.power = {
	["MANA"]		= {0/255, 144/255, 255/255 },
	["RAGE"]		= {255/255, 0/255, 0/255 },
	["FOCUS"]		= {255/255, 150/255, 26/255 },
	["ENERGY"]		= {255/255, 225/255, 26/255 },
	["RUNIC_POWER"]		= {0.44, 0.44, 0.44 },
-- vehicle colors
	["AMMOSLOT"]		= { 0.80, 0.60, 0.00 },
	["FUEL"]		= { 0.0, 0.55, 0.5 },
	["POWER_TYPE_STEAM"]	= {0.55, 0.57, 0.61},
	["POWER_TYPE_PYRITE"]	= {0.60, 0.09, 0.17},	
}
local colors = {
	class ={
	["HUNTER"]		= {0.29, 0.89, 0.05 },
	["WARLOCK"]		= {0.49, 0.15, 0.8 },
	["PRIEST"]		= {1.0, 1.0, 1.0 },
	["PALADIN"]		= {0.96, 0.55, 0.73 },
	["MAGE"]		= {0, 0.75, 1 },
	["ROGUE"]		= {0.99, 0.82, 0.09 },
	["DRUID"]		= {1.0, 0.47, 0.13 },
	["SHAMAN"]		= {0.14, 0.35, 1.0 };
	["WARRIOR"]		= {0.78, 0.61, 0.43 },
 	["DEATHKNIGHT"]		= {0.77, 0.12 , 0.23 },
	},
}
setmetatable(colors.class, {
	__index = function(self, key)
		return { 0.78, 0.61, 0.43 }
	end
})
local GetClassColor = function(unit)
	return unpack(colors.class[select(2, UnitClass(unit))])
end

-- health color gradient
oUF.colors.smooth = {0.69, 0.31, 0.31, 0.65, 0.63, 0.35, 0.15, 0.15, 0.15}
local color_rb = 0
local color_gb = 0
local color_bb = 0
local alpha_fb = 0.35
local corb = 1
local cogb = 0
local cobb = 0

-- ------------------------------------------------------------------------
-- Menu
-- ------------------------------------------------------------------------
local menu = function(self)
	local unit = self.unit:sub(1, -2)
	local cunit = self.unit:gsub("(.)", string.upper, 1)

	if(unit == "party" or unit == "partypet") then
		ToggleDropDownMenu(1, nil, _G["PartyMemberFrame"..self.id.."DropDown"], "cursor", 0, 0)
	elseif(_G[cunit.."FrameDropDown"]) then
		ToggleDropDownMenu(1, nil, _G[cunit.."FrameDropDown"], "cursor", 0, 0)
	end
end

-- ------------------------------------------------------------------------
-- Reformat everything above 9999, i.e. 10000 -> 10k
-- ------------------------------------------------------------------------
local ShortValue = function(v)
	if v <= 9999 then return v end
	if v >= 1000000 then
		local value = string.format("%.1fm", v/1000000)
		return value
	elseif v >= 10000 then
		local value = string.format("%.1fk", v/1000)
		return value
	end
end
local ShortValue_raid = function(v)
	if v <= 999 then return v end
	if v >= 1000000 then
		local value = string.format("%.1fm", v/1000000)
		return value
	elseif v >= 1000 then
		local value = string.format("%.1fk", v/1000)
		return value
	end
end

-- ------------------------------------------------------------------------
-- Level Update
-- ------------------------------------------------------------------------
local updateLevel = function(self, unit, name)
	local lvl = UnitLevel(unit)
	local typ = UnitClassification(unit)
	
	local color = GetQuestDifficultyColor(lvl)  
        
	if lvl <= 0 then	lvl = "??" end
            
	if typ=="worldboss" then
	    self.Level:SetText("|cffff0000"..lvl.."b|r")
	elseif typ=="rareelite" then
	    self.Level:SetText(lvl.."r+")
		self.Level:SetTextColor(color.r, color.g, color.b)
	elseif typ=="elite" then
	    self.Level:SetText(lvl.."+")
		self.Level:SetTextColor(color.r, color.g, color.b)
	elseif typ=="rare" then
		self.Level:SetText(lvl.."r")
		self.Level:SetTextColor(color.r, color.g, color.b)
	else
		if UnitIsConnected(unit) == 1 then
			self.Level:SetText(lvl)
		else
			self.Level:SetText("??")
		end
		if(not UnitIsPlayer(unit)) then  
			self.Level:SetTextColor(color.r, color.g, color.b)
		else
			local _, class = UnitClass(unit) 
			color = self.colors.class[class] 
			self.Level:SetTextColor(color[1], color[2], color[3])  
		end			
	end
end

-- ------------------------------------------------------------------------
-- Name Update
-- ------------------------------------------------------------------------
local updateName = function(self, event, unit)
	if(self.unit ~= unit) then return end
	local name = UnitName(unit)
	self.Name:SetText((name):sub(1, 35, nil))
		if unit=="targettarget" then
			local totName = UnitName(unit)
			local pName = UnitName("player")
				if totName==pName then
					self.Name:SetTextColor(0.9, 0.5, 0.2)
				else
					self.Name:SetTextColor(1,1,1)
				end
		else
			self.Name:SetTextColor(1,1,1)
		end
		if unit=="target" then -- Show level value on targets only
			updateLevel(self, unit, name)      
		end
	end


-- ------------------------------------------------------------------------
-- Health Update
-- ------------------------------------------------------------------------
local updateHealth = function(self, event, unit, bar, min, max)  
    local cur, maxhp = min, max
    local d = floor(cur/maxhp*100)
	if(UnitIsDead(unit) or UnitIsGhost(unit)) then
		bar:SetValue(0)
		bar.value:SetText"dead"
	elseif(not UnitIsConnected(unit)) then
		bar.value:SetText"D/C"
	elseif(unit == "player") then
		if(min ~= max) then
			bar.value:SetText("|cff33EE44"..ShortValue(cur) .."|r  ".. d.."%")
		else
			bar.value:SetText(" ")
		end
	elseif(unit == "targettarget") then
		bar.value:SetText(d.."%")
	elseif(unit == "target") then
		if(d < 100) then
			bar.value:SetText("|cff33EE44"..ShortValue(cur).."|r  "..d.."%")
		else
			bar.value:SetText(" ")
		end
	elseif(min == max) then
        if unit == "pet" then
			bar.value:SetText(" ") -- just here if otherwise wanted
	else
			bar.value:SetText(" ")
		end
	else
        if((max-min) < max) then
		if unit == "pet" then
			bar.value:SetText("|cff33EE44"..ShortValue(cur) .."|r  ".. d.."%") -- just here if otherwise wanted
		else
			bar.value:SetText("-"..maxhp-cur) -- just here if otherwise wanted
		end
	end
    end
    self:UNIT_NAME_UPDATE(event, unit)
end

-- ------------------------------------------------------------------------
-- Power Update
-- ------------------------------------------------------------------------
local updatePower = function(self, event, unit, bar, min, max)  

	if UnitIsPlayer(unit)==nil then 
		bar.value:SetText()
	else
		local _, ptype = UnitPowerType(unit)
		local color = oUF.colors.power[ptype]
		if(min==0) then 
			bar.value:SetText()
		elseif(UnitIsDead(unit) or UnitIsGhost(unit)) then
			bar:SetValue(0)
		elseif(not UnitIsConnected(unit)) then
			bar.value:SetText()
		elseif unit=="player" then 
			if((max-min) > 0) then
	            bar.value:SetText(min)
				if color then
					bar.value:SetTextColor(color[1], color[2], color[3])
				else
					bar.value:SetTextColor(0.2, 0.66, 0.93)
				end
			elseif(min==max) then
				bar.value:SetText("")
	        else
				bar.value:SetText(min)
				if color then
					bar.value:SetTextColor(color[1], color[2], color[3])
				else
					bar.value:SetTextColor(0.2, 0.66, 0.93)
				end
			end
        else
			if((max-min) > 0) then
				bar.value:SetText(min)
				if color then
					bar.value:SetTextColor(color[1], color[2], color[3])
				else
					bar.value:SetTextColor(0.2, 0.66, 0.93)
				end
			else
				bar.value:SetText(min)
				if color then
					bar.value:SetTextColor(color[1], color[2], color[3])
				else
					bar.value:SetTextColor(0.2, 0.66, 0.93)
				end
			end
		end
	end
end

-- ------------------------------------------------------------------------
-- Druid Power Update
-- ------------------------------------------------------------------------
oUF.TagEvents["[druidpower]"] = "UNIT_MANA UPDATE_SHAPESHIFT_FORM"
oUF.Tags["[druidpower]"] = function(unit)
    local min, max = UnitPower(unit, 0), UnitPowerMax(unit, 0)
    return UnitPowerType(unit)~=0 and format("|cff0090ff%s %.1f|r", tostring(siValue(min)), (min/max)*100)
end

-- ------------------------------------------------------------------------
-- Buff Icon Border Skin
-- ------------------------------------------------------------------------
local auraIcon = function(self, button, icons)
	icons.showDebuffType = true -- show debuff border type color  
	
	button.icon:SetTexCoord(.07, .93, .07, .93)
	button.icon:SetPoint("TOPLEFT", button, "TOPLEFT", 1, -1)
	button.icon:SetPoint("BOTTOMRIGHT", button, "BOTTOMRIGHT", -1, 1)
	
	button.overlay:SetTexture(bborder)
	button.overlay:SetTexCoord(0,1,0,1)
	button.overlay.Hide = function(self) self:SetVertexColor(0.3, 0.3, 0.3) end
	
	button.cd:SetReverse()
	button.cd:SetPoint("TOPLEFT", button, "TOPLEFT", 2, -2) 
	button.cd:SetPoint("BOTTOMRIGHT", button, "BOTTOMRIGHT", -2, 2)     
	button:SetScript('OnMouseUp', function(self, mouseButton)
		if(mouseButton == 'RightButton' and not debuff) then
			CancelUnitBuff('player', index)
		end
	end)
end

-- ------------------------------------------------------------------------
-- Layout
-- ------------------------------------------------------------------------
local func = function(self, unit)
	self.menu = menu -- Enable the menus

	self:SetScript("OnEnter", UnitFrame_OnEnter)
	self:SetScript("OnLeave", UnitFrame_OnLeave)
    
	self:RegisterForClicks"anyup"
	self:SetAttribute("*type2", "menu")

	self.disallowVehicleSwap = true	

	-- ---------------------------------
	-- background
	-- ---------------------------------
	local backdrop = {
		bgFile = [=[Interface\ChatFrame\ChatFrameBackground]=],
		insets = {top = -1, left = -1, bottom = -1, right = -1},
	}
	self:SetBackdrop(backdrop)
	self:SetBackdropColor(0,0,0,0.6)

	-- ---------------------------------
	-- border
	-- ---------------------------------
	local TopLeft = self:CreateTexture(nil, "OVERLAY")
	TopLeft:SetTexture(frameborder)
	TopLeft:SetTexCoord(0, 1/3, 0, 1/3)
	TopLeft:SetPoint("TOPLEFT", self, -6, 6)
	TopLeft:SetWidth(14) TopLeft:SetHeight(14)
	TopLeft:SetVertexColor(color_rb,color_gb,color_bb,alpha_fb)

	local TopRight = self:CreateTexture(nil, "OVERLAY")
	TopRight:SetTexture(frameborder)
	TopRight:SetTexCoord(2/3, 1, 0, 1/3)
	TopRight:SetPoint("TOPRIGHT", self, 6, 6)
	TopRight:SetWidth(14) TopRight:SetHeight(14)
	TopRight:SetVertexColor(color_rb,color_gb,color_bb,alpha_fb)

	local BottomLeft = self:CreateTexture(nil, "OVERLAY")
	BottomLeft:SetTexture(frameborder)
	BottomLeft:SetTexCoord(0, 1/3, 2/3, 1)
	BottomLeft:SetPoint("BOTTOMLEFT", self, -6, -6)
	BottomLeft:SetWidth(14) BottomLeft:SetHeight(14)
	BottomLeft:SetVertexColor(color_rb,color_gb,color_bb,alpha_fb)

	local BottomRight = self:CreateTexture(nil, "OVERLAY")
	BottomRight:SetTexture(frameborder)
	BottomRight:SetTexCoord(2/3, 1, 2/3, 1)
	BottomRight:SetPoint("BOTTOMRIGHT", self, 6, -6)
	BottomRight:SetWidth(14) BottomRight:SetHeight(14)
	BottomRight:SetVertexColor(color_rb,color_gb,color_bb,alpha_fb)

	local TopEdge = self:CreateTexture(nil, "OVERLAY")
	TopEdge:SetTexture(frameborder)
	TopEdge:SetTexCoord(1/3, 2/3, 0, 1/3)
	TopEdge:SetPoint("TOPLEFT", TopLeft, "TOPRIGHT")
	TopEdge:SetPoint("TOPRIGHT", TopRight, "TOPLEFT")
	TopEdge:SetHeight(14)
	TopEdge:SetVertexColor(color_rb,color_gb,color_bb,alpha_fb)
		
	local BottomEdge = self:CreateTexture(nil, "OVERLAY")
	BottomEdge:SetTexture(frameborder)
	BottomEdge:SetTexCoord(1/3, 2/3, 2/3, 1)
	BottomEdge:SetPoint("BOTTOMLEFT", BottomLeft, "BOTTOMRIGHT")
	BottomEdge:SetPoint("BOTTOMRIGHT", BottomRight, "BOTTOMLEFT")
	BottomEdge:SetHeight(14)
	BottomEdge:SetVertexColor(color_rb,color_gb,color_bb,alpha_fb)
		
	local LeftEdge = self:CreateTexture(nil, "OVERLAY")
	LeftEdge:SetTexture(frameborder)
	LeftEdge:SetTexCoord(0, 1/3, 1/3, 2/3)
	LeftEdge:SetPoint("TOPLEFT", TopLeft, "BOTTOMLEFT")
	LeftEdge:SetPoint("BOTTOMLEFT", BottomLeft, "TOPLEFT")
	LeftEdge:SetWidth(14)
	LeftEdge:SetVertexColor(color_rb,color_gb,color_bb,alpha_fb)
		
	local RightEdge = self:CreateTexture(nil, "OVERLAY")
	RightEdge:SetTexture(frameborder)
	RightEdge:SetTexCoord(2/3, 1, 1/3, 2/3)
	RightEdge:SetPoint("TOPRIGHT", TopRight, "BOTTOMRIGHT")
	RightEdge:SetPoint("BOTTOMRIGHT", BottomRight, "TOPRIGHT")
	RightEdge:SetWidth(14)
	RightEdge:SetVertexColor(color_rb,color_gb,color_bb,alpha_fb)	
	
	-- ---------------------------------
	-- healthbar
	-- ---------------------------------
	self.Health = CreateFrame"StatusBar"
	self.Health:SetHeight(26) 
	self.Health:SetStatusBarTexture(texture)
	self.Health:SetParent(self)
	self.Health:SetPoint"TOP"
	self.Health:SetPoint"LEFT"
	self.Health:SetPoint"RIGHT"
	
	-- ---------------------------------
	-- healthbar background
	-- ---------------------------------
	self.Health.bg = self.Health:CreateTexture(nil, "BORDER")
	self.Health.bg:SetAllPoints(self.Health)
	self.Health.bg:SetTexture(texture)
	self.Health.bg:SetAlpha(0.30)  
	
	-- ---------------------------------
	-- healthbar text
	-- ---------------------------------
	self.Health.value = self.Health:CreateFontString(nil, "OVERLAY")
	self.Health.value:SetPoint("RIGHT", -2, 2)
	self.Health.value:SetFont(font, fontsize, "OUTLINE")
	self.Health.value:SetTextColor(1,1,1)
	self.Health.value:SetShadowOffset(1, -1)

	-- ---------------------------------
	-- healthbar functions
	-- ---------------------------------
	self.Health.colorClass = true 
	self.Health.colorReaction = true 
	self.Health.colorDisconnected = true 
	self.Health.colorTapping = true  
	self.PostUpdateHealth = updateHealth 
	self.Health.frequentUpdates = true

	-- ---------------------------------
	-- powerbar
	-- ---------------------------------
	self.Power = CreateFrame"StatusBar"
	self.Power:SetHeight(6)
	self.Power:SetStatusBarTexture(texture)
	self.Power:SetParent(self)
	self.Power:SetPoint"LEFT"
	self.Power:SetPoint"RIGHT"
	self.Power:SetPoint("TOP", self.Health, "BOTTOM", 0, -1.45) -- Little offset to make it pretty

	-- ---------------------------------
	-- powerbar background
	-- ---------------------------------
	self.Power.bg = self.Power:CreateTexture(nil, "BORDER")
	self.Power.bg:SetAllPoints(self.Power)
	self.Power.bg:SetTexture(texture)
	self.Power.bg:SetAlpha(0.30)  

	-- ---------------------------------
	-- powerbar text
	-- ---------------------------------
	self.Power.value = self.Power:CreateFontString(nil, "OVERLAY")
	self.Power.value:SetPoint("RIGHT", self.Health.value, "BOTTOMRIGHT", 0, -5) -- powerbar text anchored to health box
	self.Power.value:SetFont(font, fontsize, "OUTLINE")
	self.Power.value:SetTextColor(1,1,1)
	self.Power.value:SetShadowOffset(1, -1)
	self.Power.value:Hide()
    
	-- ---------------------------------
	-- powerbar functions
	-- ---------------------------------
	self.Power.colorTapping = true 
	self.Power.colorDisconnected = true 
	self.Power.colorClass = true 
	self.Power.colorPower = true 
	self.Power.colorHappiness = false  
	self.PostUpdatePower = updatePower 

	-- ---------------------------------
	-- names
	-- ---------------------------------
	self.Name = self.Health:CreateFontString(nil, "OVERLAY")
	self.Name:SetPoint("LEFT", self, 0, 9)
	self.Name:SetJustifyH"LEFT"
	self.Name:SetFont(font, fontsize, "OUTLINE")
	self.Name:SetShadowOffset(1, -1)
	self.UNIT_NAME_UPDATE = updateName

	-- ---------------------------------
	-- level
	-- ---------------------------------
	self.Level = self.Health:CreateFontString(nil, "OVERLAY")
	self.Level:SetPoint("CENTER", oUF_Target, "TOPLEFT", -100, 0)
	self.Level:SetJustifyH("LEFT")
	self.Level:SetFont(font, fontsize, "OUTLINE")
	self.Level:SetTextColor(1,1,1)
	self.Level:SetShadowOffset(1, -1)
	self.UNIT_LEVEL = updateLevel
	
	-- ---------------------------------
	-- oUF_SpellRange fading and oUF_Smooth Support 
	-- ---------------------------------
	if(self:GetParent():GetName():match"oUF_Raid") or (self:GetParent():GetName():match"oUF_Party") then 
		self.SpellRange = true; -- fadeout if units are out of range
		self.inRangeAlpha = 1.0; -- Frame alpha when in range
		self.outsideRangeAlpha = 0.3; -- Frame alpha when out of range
		self.Power.Smooth = true
		self.Health.Smooth = true
	end
        
	-- ---------------------------------
	-- oUF_DebuffHighlight support
	-- ---------------------------------
	if unit=="player" or unit=="target" or unit=="pet" or (self:GetParent():GetName():match"oUF_Party") then
		self.DebuffHighlight = self:CreateTexture(nil, "OVERLAY")
		self.DebuffHighlight:SetPoint("TOPLEFT",self,"TOPLEFT",-4,4)
		self.DebuffHighlight:SetPoint("BOTTOMRIGHT",self,"BOTTOMRIGHT",4,-4)
		self.DebuffHighlight:SetTexture(debufftex)
		self.DebuffHighlight:SetVertexColor(0, 0, 0, 0)
		self.DebuffHighlight:SetBlendMode("BLEND")
		self.DebuffHighlightAlpha = 0.9
		self.DebuffHighlightFilter = true
	elseif(self:GetParent():GetName():match"oUF_Raid") then
		self.DebuffHighlight = self:CreateTexture(nil, "OVERLAY")
		self.DebuffHighlight:SetPoint("TOPLEFT",self,"TOPLEFT",-4,4)
		self.DebuffHighlight:SetPoint("BOTTOMRIGHT",self,"BOTTOMRIGHT",4,-4)
		self.DebuffHighlight:SetTexture(debufftex2)
		self.DebuffHighlight:SetVertexColor(0, 0, 0, 0)
		self.DebuffHighlight:SetBlendMode("BLEND")		
		self.DebuffHighlightAlpha = 0.9
		self.DebuffHighlightFilter = true
	end
    
	-- ------------------------------------
	-- player
	-- ------------------------------------
	if unit=="player" then
		self:SetWidth(250)
	      	self:SetHeight(30)
		self.Name:SetPoint("BOTTOMLEFT", self.Health, "TOPRIGHT", 7, -10)
		self.Name:SetHeight(20)
		self.Name:SetWidth(154)
		self.Health.value:SetPoint("RIGHT", 0, 9)
		self.Health:SetHeight(23)
		self.Health.frequentUpdates = true
		self.Health.Smooth = true
		self.Health:SetAlpha(0.7)
		self.Power.Smooth = true
		self.Power.frequentUpdates = true
		self.Power:SetHeight(6)
		self.Power.value:Show()
		self.Power.value:SetPoint("LEFT", self.Power, 0, 1)
		self.Power.value:SetJustifyH"LEFT"
		self.Power:SetAlpha(0.7)
		self.Portrait = CreateFrame('PlayerModel', nil, self)
		self.Portrait:SetPoint('TOPLEFT', self.Health)
		self.Portrait:SetPoint('BOTTOMLEFT', self.Health)
		self.Portrait:SetAlpha(0.1)
		self.Portrait:SetWidth(250)
		self.Level:Hide()

	-- ---------------------------------
	-- resting icon
	-- ---------------------------------
		self.Resting = self.Health:CreateTexture(nil, 'OVERLAY')
		self.Resting:SetHeight(20)
		self.Resting:SetWidth(24)
		self.Resting:SetPoint('BOTTOMLEFT', self, 0, 0)
		self.Resting:SetTexture([=[Interface\CharacterFrame\UI-StateIcon]=])
		self.Resting:SetTexCoord(0,0.5,0,0.421875)
		    
	-- ---------------------------------
	-- oUF_BarFader
	-- ---------------------------------
		self.BarFade = true

	-- ---------------------------------
	-- leader icon
	-- ---------------------------------
		self.Leader = self.Health:CreateTexture(nil, "OVERLAY")
		self.Leader:SetHeight(16)
		self.Leader:SetWidth(16)
		self.Leader:SetPoint("BOTTOMRIGHT", self, -2, 4)
		self.Leader:SetTexture('Interface\\GroupFrame\\UI-Group-LeaderIcon')

	-- ---------------------------------
	-- Combat icon
	-- ---------------------------------
		self.Combat = self.Health:CreateTexture(nil, 'OVERLAY')
		self.Combat:SetHeight(20)
		self.Combat:SetWidth(20)
		self.Combat:SetPoint('BOTTOMLEFT', self, 0, -9)
		self.Combat:SetTexture('Interface\\CharacterFrame\\UI-StateIcon')
		self.Combat:SetTexCoord(0.58, 0.90, 0.08, 0.41)

	-- ---------------------------------
	-- raid target icons
	-- ---------------------------------
		self.RaidIcon = self.Health:CreateTexture(nil, "OVERLAY")
		self.RaidIcon:SetHeight(16)
		self.RaidIcon:SetWidth(16)
		self.RaidIcon:SetPoint("TOP", self, 0, 9)
		self.RaidIcon:SetTexture('Interface\\TargetingFrame\\UI-RaidTargetingIcons')

	-- ---------------------------------
	-- oUF_PowerSpark support
	-- ---------------------------------
		self.Spark = self.Power:CreateTexture(nil, "OVERLAY")
		self.Spark:SetTexture('Interface\\CastingBar\\UI-CastingBar-Spark')
		self.Spark:SetVertexColor(1, 1, 1, 1)
		self.Spark:SetBlendMode("ADD")
		self.Spark:SetHeight(self.Power:GetHeight()*2.5)
		self.Spark:SetWidth(self.Power:GetHeight()*2)
		-- self.Spark.rtl = true -- Make the spark go from Right To Left instead
		-- self.Spark.manatick = true -- Show mana regen ticks outside FSR (like the energy ticker)
		-- self.Spark.highAlpha = 1 	-- What alpha setting to use for the FSR and energy spark
		-- self.Spark.lowAlpha = 0.25 -- What alpha setting to use for the mana regen ticker

	-- ------------------------------------
	-- PvP Icon
	-- ------------------------------------
		local pvp = self.Health:CreateTexture(nil, "OVERLAY")
		pvp:SetPoint("LEFT", self.Health, "LEFT", -12, 6)
		pvp:SetHeight(36)
		pvp:SetWidth(36)
		self.PvP = pvp

	end

	-- ------------------------------------
	-- pet
	-- ------------------------------------
	if unit=="pet" then
		self:SetWidth(120)
		self:SetHeight(18)
		self.Health:SetHeight(15)
		self.Power:SetHeight(3)
		self.Power.Smooth = true
		self.Health.Smooth = true
		self.Power.value:Hide()
		--self.Health.value:Hide()
		self.Level:Hide()
		self.Name:Hide()
		self.Power:SetAlpha(0.7)
		self.Health:SetAlpha(0.7)
		
		if playerClass=="HUNTER" then
			self.Health.colorReaction = false
			self.Health.colorClass = false
			self.Health.colorHappiness = true  
			self.Name:Show()
		end

	-- ------------------------------------
	-- oUF_BarFader
	-- ------------------------------------
		self.BarFade = true
	end

	-- ------------------------------------
	-- target
	-- ------------------------------------
	if unit=="target" then
		self:SetWidth(145)
		self:SetHeight(30)
		
		self.Health:SetHeight(23)
		self.Health.colorTapping = true
		self.Health.colorDisconnected = true
		self.Health.colorClass = true
		self.Health.colorReaction = true
		self.Health.frequentUpdates = true
		self.Health.Smooth = true
		self.Health.value:SetPoint("RIGHT", 0, 9)
		self.Health:SetAlpha(0.8)

		self.Power:SetHeight(6)
		self.Power.value:Hide()
		self.Power.Smooth = true
		self.Power.frequentUpdates = true
		self.Power:SetAlpha(0.8)
		
		self.Name:SetPoint("LEFT", self.Level, "RIGHT", 0, 0)
		self.Name:SetHeight(20)
		self.Name:SetWidth(230)
		
	-- ------------------------------------
	-- Portrait
	-- ------------------------------------
		local portrait = CreateFrame("PlayerModel", nil, self)
		portrait:SetScript("OnShow", function(self) self:SetCamera(0) end)
		portrait:SetWidth(90)
		portrait:SetHeight(100)
		portrait:SetPoint("TOPRIGHT", oUF_Target, "TOPLEFT", -13, 0)
		portrait.type = "3D"
		self.Portrait = portrait
		portrait:SetFrameLevel(0)
		TargetPorBG = CreateFrame('Frame', 'TargetBG', oUF_Target)
		TargetPorBG:SetFrameStrata'BACKGROUND'
		TargetPorBG:SetWidth(102)
		TargetPorBG:SetHeight(112)
		TargetPorBG:SetPoint("TOPRIGHT", oUF_Target, "TOPLEFT", -8, 6)
		TargetPorBG:SetBackdrop({bgFile = "Interface\\ChatFrame\\ChatFrameBackground",edgeFile = "Interface\\Tooltips\\ChatBubble-Backdrop",tile = false, tileSize = 0,edgeSize = 9,insets = { left = 6, right = 6, top = 6, bottom = 6 }})
		TargetPorBG:SetBackdropColor(0,0,0,0.8)
		TargetPorBG:SetBackdropBorderColor(0.2,0.5,0.5,0.35)		
	
	-- ------------------------------------
	-- PvP Icon
	-- ------------------------------------
		local pvp = self.Health:CreateTexture(nil, "OVERLAY")
		pvp:SetPoint("CENTER", self.Portrait, "BOTTOMRIGHT", 5, -5)
		pvp:SetHeight(36)
		pvp:SetWidth(36)
		self.PvP = pvp

	-- ------------------------------------
	-- buffs
	-- ------------------------------------
		self.Buffs = CreateFrame("Frame", nil, self) -- buffs
		self.Buffs.size = 30
		self.Buffs:SetHeight(self.Buffs.size)
		self.Buffs:SetWidth(self.Buffs.size * 6)
		self.Buffs:SetPoint("BOTTOMLEFT", self, "RIGHT", 15, -10)
		self.Buffs.initialAnchor = "BOTTOMLEFT"
		self.Buffs["growth-y"] = "TOP"
		self.Buffs.num = 30
		self.Buffs.spacing = 2
		
	-- ------------------------------------
	-- debuffs
	-- ------------------------------------
		self.Debuffs = CreateFrame("Frame", nil, self)
		self.Debuffs.size = 36
		self.Debuffs:SetHeight(self.Debuffs.size)
		self.Debuffs:SetWidth(self.Debuffs.size * 8)
		self.Debuffs:SetPoint("TOPLEFT", self, "BOTTOMLEFT", -2, -6)
		self.Debuffs.initialAnchor = "TOPLEFT"
		self.Debuffs["growth-y"] = "DOWN"
		self.Debuffs.filter = "HARMFUL|PLAYER"
		self.Debuffs.num = 40
		self.Debuffs.spacing = 2
	
	-- ------------------------------------
	-- raid target icons
	-- ------------------------------------
		self.RaidIcon = self.Health:CreateTexture(nil, "OVERLAY")
		self.RaidIcon:SetHeight(24)
		self.RaidIcon:SetWidth(24)
		self.RaidIcon:SetPoint("TOPRIGHT", self.Portrait, "TOPRIGHT", 5, -8)
		self.RaidIcon:SetTexture"Interface\\TargetingFrame\\UI-RaidTargetingIcons"
	end

	-- ------------------------------------
	-- Target of Target
	-- ------------------------------------
	if unit=="targettarget" then
		self:SetWidth(250)
		self:SetHeight(18)
		self.Health:SetHeight(18)
		self.Health.colorTapping = true
		self.Health.colorDisconnected = true
		self.Health.colorClass = true
		self.Health.colorReaction = true
		self.Power:Hide()
		self.Power.value:Hide()
		self.Health.value:Hide()
		self.Name:SetWidth(145)
		self.Name:SetHeight(18)
		self.Power:SetAlpha(0.8)
		self.Health:SetAlpha(0.8)

		self.Portrait = CreateFrame('PlayerModel', nil, self)
		self.Portrait:SetPoint('TOPLEFT', self.Health)
		self.Portrait:SetPoint('BOTTOMLEFT', self.Health)
		self.Portrait:SetAlpha(0.1)
		self.Portrait:SetWidth(250)

	-- ------------------------------------
	-- raid target icons
	-- ------------------------------------
		self.RaidIcon = self.Health:CreateTexture(nil, "OVERLAY")
		self.RaidIcon:SetHeight(16)
		self.RaidIcon:SetWidth(16)
		self.RaidIcon:SetPoint("RIGHT", self, 0, 9)
		self.RaidIcon:SetTexture"Interface\\TargetingFrame\\UI-RaidTargetingIcons"
	end
    
	-- ------------------------------------
	-- focus target 
	-- ------------------------------------
	if unit=="focus" then
		self:SetWidth(120)
		self:SetHeight(18)
		self.Health:SetHeight(18)
		self.Health.colorTapping = true
		self.Health.colorDisconnected = true
		self.Health.colorClass = true
		self.Health.colorReaction = true
		self.Power:Hide()
		self.Power.value:Hide()
		self.Health.value:Hide()
		self.Name:SetWidth(95)
		self.Name:SetHeight(18)
		self.Power:SetAlpha(0.8)
		self.Health:SetAlpha(0.8)
		
	-- ------------------------------------
	-- oUF_BarFader
	-- ------------------------------------
		if unit=="focus" then
			self.BarFade = false
		end
	end

	-- ------------------------------------
	-- Player and Target Castbars 	
	-- ------------------------------------
		if(unit == 'player' or unit == 'target' or unit == 'focus') then
		self.Castbar = CreateFrame('StatusBar', nil, self)
		self.Castbar:SetStatusBarTexture(casttex)
	    		
		if(unit == "player") then
			local _, class = UnitClass(unit) 
			color = self.colors.class[class] 
			self.Castbar:SetStatusBarColor(color[1], color[2], color[3]) 
			self.Castbar:SetHeight(14)
			self.Castbar:SetWidth(213)

			self.Castbar:SetBackdrop{
				bgFile = "Interface\\ChatFrame\\ChatFrameBackground", tile = true, tileSize = 16,
				insets = {left = -2, right = -2, top = -2, bottom = -2}}

			self.Castbar.SafeZone = self.Castbar:CreateTexture(nil,"ARTWORK")
			self.Castbar.SafeZone:SetTexture(casttex)
			self.Castbar.SafeZone:SetVertexColor(.75,.10,.10,.6)
			self.Castbar.SafeZone:SetPoint("TOPRIGHT")
			self.Castbar.SafeZone:SetPoint("BOTTOMRIGHT")
			
			self.Castbar:SetPoint('CENTER', UIParent, 'CENTER', playerCastBar_x, playerCastBar_y)

		else
			self.Castbar:SetStatusBarColor(0.80, 0.01, 0)    --target = red
			self.Castbar:SetHeight(16)
			self.Castbar:SetWidth(222)
			
			self.Castbar:SetBackdrop{
				bgFile = "Interface\\ChatFrame\\ChatFrameBackground", tile = true, tileSize = 16,
				insets = {left = -2, right = -2, top = -2, bottom = -2}}
			self.Castbar:SetPoint('CENTER', UIParent, 'CENTER', targetCastBar_x, targetCastBar_y)
		end
        
		if(unit == 'focus') then
			self.Castbar:SetStatusBarColor(0, 1, 0.2) -- focus = green
			self.Castbar:SetPoint('CENTER', UIParent, 'CENTER', focusCastBar_x, focusCastBar_y)
		end
        
		self.Castbar:SetBackdropColor(0, 0, 0, 0.5)
        
		local icon = self.Castbar:CreateTexture(nil, "ARTWORK") -- Castbar Icon
			icon:SetHeight(30)
			icon:SetWidth(30)
			icon:SetTexCoord(.07, .93, .07, .93)
			icon:SetPoint("RIGHT", self.Castbar, "LEFT", -8, 5)
			self.Castbar.Icon = icon
        
		local IconOverlay = self.Castbar:CreateTexture(nil, 'OVERLAY') 
			IconOverlay:SetPoint('TOPLEFT', icon, 'TOPLEFT', -1, 1)
			IconOverlay:SetPoint('BOTTOMRIGHT', icon, 'BOTTOMRIGHT', 1,-1)
			IconOverlay:SetTexture(bborder)
			IconOverlay:SetVertexColor(0.3, 0.3, 0.3)
			IconOverlay:SetBlendMode('BLEND')
		
			self.Castbar.Text = self.Castbar:CreateFontString(nil, 'OVERLAY')
		    	self.Castbar.Text:SetPoint('LEFT', self.Castbar, 0, 12)
		    	self.Castbar.Text:SetFont(font, fontsize-4, outline)
			self.Castbar.Text:SetShadowOffset(1, -1)
		    	self.Castbar.Text:SetTextColor(1, 1, 1)
		    	self.Castbar.Text:SetJustifyH('LEFT')

		    	self.Castbar.Time = self.Castbar:CreateFontString(nil, 'OVERLAY')
		    	self.Castbar.Time:SetPoint('RIGHT', self.Castbar, 0, 8)
		    	self.Castbar.Time:SetFont(font, fontsize, outline)
		    	self.Castbar.Time:SetTextColor(1, 1, 1)
		    	self.Castbar.Time:SetJustifyH('RIGHT')
					
			-- Castbar frameborder
			local TopLeft = self.Castbar:CreateTexture(nil, "OVERLAY")
			TopLeft:SetTexture(castborder)
			TopLeft:SetTexCoord(0, 1/3, 0, 1/3)
			TopLeft:SetPoint("TOPLEFT", -3, 3)
			TopLeft:SetWidth(14) TopLeft:SetHeight(14)
			TopLeft:SetVertexColor(color_rb,color_gb,color_bb,alpha_fb)
	
			local TopRight = self.Castbar:CreateTexture(nil, "OVERLAY")
			TopRight:SetTexture(castborder)
			TopRight:SetTexCoord(2/3, 1, 0, 1/3)
			TopRight:SetPoint("TOPRIGHT", 3, 3)
			TopRight:SetWidth(14) TopRight:SetHeight(14)
			TopRight:SetVertexColor(color_rb,color_gb,color_bb,alpha_fb)

			local BottomLeft = self.Castbar:CreateTexture(nil, "OVERLAY")
			BottomLeft:SetTexture(castborder)
			BottomLeft:SetTexCoord(0, 1/3, 2/3, 1)
			BottomLeft:SetPoint("BOTTOMLEFT", -3, -3)
			BottomLeft:SetWidth(14) BottomLeft:SetHeight(14)
			BottomLeft:SetVertexColor(color_rb,color_gb,color_bb,alpha_fb)

			local BottomRight = self.Castbar:CreateTexture(nil, "OVERLAY")
			BottomRight:SetTexture(castborder)
			BottomRight:SetTexCoord(2/3, 1, 2/3, 1)
			BottomRight:SetPoint("BOTTOMRIGHT", 3, -3)
			BottomRight:SetWidth(14) BottomRight:SetHeight(14)
			BottomRight:SetVertexColor(color_rb,color_gb,color_bb,alpha_fb)

			local TopEdge = self.Castbar:CreateTexture(nil, "OVERLAY")
			TopEdge:SetTexture(castborder)
			TopEdge:SetTexCoord(1/3, 2/3, 0, 1/3)
			TopEdge:SetPoint("TOPLEFT", TopLeft, "TOPRIGHT")
			TopEdge:SetPoint("TOPRIGHT", TopRight, "TOPLEFT")
			TopEdge:SetHeight(14)
			TopEdge:SetVertexColor(color_rb,color_gb,color_bb,alpha_fb)
		
			local BottomEdge = self.Castbar:CreateTexture(nil, "OVERLAY")
			BottomEdge:SetTexture(castborder)
			BottomEdge:SetTexCoord(1/3, 2/3, 2/3, 1)
			BottomEdge:SetPoint("BOTTOMLEFT", BottomLeft, "BOTTOMRIGHT")
			BottomEdge:SetPoint("BOTTOMRIGHT", BottomRight, "BOTTOMLEFT")
			BottomEdge:SetHeight(14)
			BottomEdge:SetVertexColor(color_rb,color_gb,color_bb,alpha_fb)
		
			local LeftEdge = self.Castbar:CreateTexture(nil, "OVERLAY")
			LeftEdge:SetTexture(castborder)
			LeftEdge:SetTexCoord(0, 1/3, 1/3, 2/3)
			LeftEdge:SetPoint("TOPLEFT", TopLeft, "BOTTOMLEFT")
			LeftEdge:SetPoint("BOTTOMLEFT", BottomLeft, "TOPLEFT")
			LeftEdge:SetWidth(14)
			LeftEdge:SetVertexColor(color_rb,color_gb,color_bb,alpha_fb)
		
			local RightEdge = self.Castbar:CreateTexture(nil, "OVERLAY")
			RightEdge:SetTexture(castborder)
			RightEdge:SetTexCoord(2/3, 1, 1/3, 2/3)
			RightEdge:SetPoint("TOPRIGHT", TopRight, "BOTTOMRIGHT")
			RightEdge:SetPoint("BOTTOMRIGHT", BottomRight, "TOPRIGHT")
			RightEdge:SetWidth(14)
			RightEdge:SetVertexColor(color_rb,color_gb,color_bb,alpha_fb)
	end

	-- ------------------------------------
	-- Party 
	-- ------------------------------------
	if(self:GetParent():GetName():match"oUF_Party") then
		self:SetWidth(160)
		self:SetHeight(20)
		self.Health:SetHeight(15)
		self.Health.colorTapping = true
		self.Health.colorDisconnected = true
		self.Health.colorClass = true
		self.Health.colorReaction = true
		self.Power.Smooth = true
		self.Health.Smooth = true
		self.Power:SetHeight(3)
		self.Power.value:Hide()
		self.Health.value:SetPoint("RIGHT", 0 , 9)
		self.Name:SetPoint("LEFT", 0, 9)
		self.Power:SetAlpha(0.8)
		self.Health:SetAlpha(0.8)

	-- ------------------------------------
	-- Leader Icon
	-- ------------------------------------
		self.Leader = self.Health:CreateTexture(nil, "OVERLAY")
		self.Leader:SetHeight(14)
		self.Leader:SetWidth(14)
		self.Leader:SetPoint("TOPLEFT", self, -10, 12)
		self.Leader:SetTexture"Interface\\GroupFrame\\UI-Group-LeaderIcon"

		self.MasterLooter = self.Health:CreateTexture(nil, 'OVERLAY')
		self.MasterLooter:SetHeight(14)
		self.MasterLooter:SetWidth(14)
		self.MasterLooter:SetPoint("TOPRIGHT", self, 10, 12)
		self.MasterLooter:SetTexture"Interface\\GroupFrame\\UI-Group-MasterLooter"
		
	-- ------------------------------------
	-- Auras
	-- ------------------------------------
	--	self.Auras = CreateFrame("Frame", nil, self) -- auras
	--	self.Auras.buffFilter= "HELPFUL|RAID"
	--	self.Auras.size = 26
	--	self.Auras.gap = true
	--	self.Auras:SetHeight(self.Auras.size)
	--	self.Auras:SetWidth(self.Auras.size * 9)
	--	self.Auras:SetPoint("TOPLEFT", self, "BOTTOMLEFT", -2, -5)
	--	self.Auras.initialAnchor = "TOPLEFT"
	--	self.Auras["growth-x"] = "RIGHT"
	--	self.Auras.numBuffs = 5
	--	self.Auras.numDebuffs = 3
	--	self.Auras.spacing = 2

	-- ------------------------------------
	-- buffs
	-- ------------------------------------
		self.Buffs = CreateFrame("Frame", nil, self) -- buffs
		self.Buffs.size = 16
		self.Buffs:SetHeight(self.Buffs.size)
		self.Buffs:SetWidth(self.Buffs.size * 12)
		self.Buffs:SetPoint("BOTTOMLEFT", self, "BOTTOMLEFT", -2, -23)
		self.Buffs.initialAnchor = "BOTTOMLEFT"
		--self.Buffs["growth-y"] = "TOP"
		self.Buffs.num = 10
		self.Buffs.spacing = 2
		self.Buffs.filter = "HELPFUL|PLAYER"
		
	-- ------------------------------------
	-- debuffs
	-- ------------------------------------
		self.Debuffs = CreateFrame("Frame", nil, self)
		self.Debuffs.size = 20 * 1.3
		self.Debuffs:SetHeight(self.Debuffs.size)
		self.Debuffs:SetWidth(self.Debuffs.size * 5)
		self.Debuffs:SetPoint("LEFT", self, "RIGHT", 8, 0)
		self.Debuffs.initialAnchor = "TOPLEFT"
		self.Debuffs.filter = false
		self.Debuffs.showDebuffType = true
		self.Debuffs.spacing = 2
		self.Debuffs.num = 8 -- max debuffs

	-- ------------------------------------
	-- raid target icons
	-- ------------------------------------
		self.RaidIcon = self.Health:CreateTexture(nil, "OVERLAY")
		self.RaidIcon:SetHeight(24)
		self.RaidIcon:SetWidth(24)
		self.RaidIcon:SetPoint("LEFT", self, -30, 0)
		self.RaidIcon:SetTexture"Interface\\TargetingFrame\\UI-RaidTargetingIcons"
	end

	-- ------------------------------------
	-- Raid 
	-- ------------------------------------
if useraid == true then	
	if(self:GetParent():GetName():match"oUF_Raid") then
		self:SetWidth(70)
		self:SetHeight(20)
		self.Health:SetOrientation("HORIZONTAL")
		self.Health:SetHeight(16)
		self.Health:SetFrameLevel(2) 
		self.Health.value:SetPoint("TOP", 0, 5)
		self.Health.value:SetFont(font, 10, "OUTLINE")
		self.Health:SetAlpha(0.8)
		self.Health.colorDisconnected = true
		self.Health.colorClass = true
		self.Name:SetPoint("LEFT", 1, -1)
		self.Name:SetFont(font, 12, "OUTLINE")
		self.Power:SetFrameLevel(2)
		self.Power:SetHeight(3)
		self.Power:SetAlpha(0.8)
		self.Power.value:Hide()

	-- ------------------------------------
	-- Leader Icon
	-- ------------------------------------
		self.Leader = self.Health:CreateTexture(nil, "OVERLAY")
		self.Leader:SetHeight(14)
		self.Leader:SetWidth(14)
		self.Leader:SetPoint("TOPRIGHT", self, 6, 8)
		self.Leader:SetTexture"Interface\\GroupFrame\\UI-Group-LeaderIcon"

		self.MasterLooter = self.Health:CreateTexture(nil, 'OVERLAY')
		self.MasterLooter:SetHeight(14)
		self.MasterLooter:SetWidth(14)
		self.MasterLooter:SetPoint("TOPRIGHT", self, -6, 9)
		self.MasterLooter:SetTexture"Interface\\GroupFrame\\UI-Group-MasterLooter"
		
	-- ------------------------------------
	-- raid target icons
	-- ------------------------------------
		self.RaidIcon = self.Health:CreateTexture(nil, "OVERLAY")
		self.RaidIcon:SetHeight(16)
		self.RaidIcon:SetWidth(16)
		self.RaidIcon:SetPoint("TOPRIGHT", self, 2, 6)
		self.RaidIcon:SetTexture"Interface\\TargetingFrame\\UI-RaidTargetingIcons"

	-- ------------------------------------
	-- oUF_ReadyCheck support
	-- ------------------------------------
		self.ReadyCheck = self.Health:CreateTexture(nil, 'OVERLAY')
		self.ReadyCheck:SetPoint('LEFT', self, -18, 0)
		self.ReadyCheck:SetHeight(20)
		self.ReadyCheck:SetWidth(20)
	end
end
	-- ------------------------------------
	-- custom aura textures
	-- ------------------------------------
	self.PostCreateAuraIcon = auraIcon
	self.SetAuraPosition = auraOffset
	
	if(self:GetParent():GetName():match"oUF_Party") then
		self:SetAttribute('initial-height', 20) 
		self:SetAttribute('initial-width', 160) 
	else 
		self:SetAttribute('initial-height', height) 
		self:SetAttribute('initial-width', width) 
	end  
	
	return self   
end

-- ------------------------------------------------------------------------
-- spawning the frames
-- ------------------------------------------------------------------------

-- ------------------------------------
-- normal frames
-- ------------------------------------
oUF:RegisterStyle("Cliche", func)
oUF:SetActiveStyle("Cliche")
local player = oUF:Spawn("player", "oUF_Player")
player:SetPoint("CENTER", 0, -193)
local target = oUF:Spawn("target", "oUF_Target")
target:SetPoint("CENTER", 316, -123) 
local pet = oUF:Spawn("pet", "oUF_Pet")
pet:SetPoint("LEFT", player, -140, -40)
local tot = oUF:Spawn("targettarget", "oUF_TargetTarget")
tot:SetPoint("CENTER", 265, -83)
local focus	= oUF:Spawn("focus", "oUF_Focus")
focus:SetPoint("RIGHT", target, 200, 40) 

-- ------------------------------------
-- party
-- ------------------------------------
local party	= oUF:Spawn("header", "oUF_Party")
party:SetManyAttributes("showParty", true, "yOffset", -35)
party:SetPoint("LEFT", 12, -110)
party:Show()
--party:SetAttribute("showRaid", false)

-- ------------------------------------
-- raid
-- ------------------------------------
local raid = {}
for i = 1, 8 do
	local raidgroup = oUF:Spawn('header', 'oUF_Raid'..i)
	raidgroup:SetManyAttributes('groupFilter', tostring(i), 'showRaid', true, 'yOffSet', -12)
	table.insert(raid, raidgroup)
	if(i==1) then
		raidgroup:SetPoint('TOPLEFT', UIParent, 'TOPLEFT', 10, -10)
	else
		raidgroup:SetPoint('TOPLEFT', raid[i-1], 'TOPRIGHT', 12, 0)
	end
end

-- ------------------------------------
-- party toggle in raid
-- ------------------------------------
local partyToggle = CreateFrame('Frame')
partyToggle:RegisterEvent('PLAYER_LOGIN')
partyToggle:RegisterEvent('RAID_ROSTER_UPDATE')
partyToggle:RegisterEvent('PARTY_LEADER_CHANGED')
partyToggle:RegisterEvent('PARTY_MEMBERS_CHANGED')
partyToggle:SetScript('OnEvent', function(self)
	if(InCombatLockdown()) then
		self:RegisterEvent('PLAYER_REGEN_ENABLED')
	else
		self:UnregisterEvent('PLAYER_REGEN_ENABLED')
		if(GetNumRaidMembers() > 5) then
			party:Hide()
			for i,v in ipairs(raid) do v:Show() end
			--for i,v in ipairs(partypet) do v:Disable()	end
			--for i,v in ipairs(partytarget) do v:Disable()	end
		else
			party:Show()
			for i,v in ipairs(raid) do v:Hide() end
			--for i,v in ipairs(partypet) do v:Enable() end
			--for i,v in ipairs(partytarget) do v:Enable() end
		end
	end
end)